<?php
namespace Planejamento\Repositories;

class Recefili extends \Doctrine\ORM\EntityRepository
{

    public static function verificaProdInativoFilial($nrorg, $filial, $prato, $filAux, $maxNivelProd)
    {
        $query = "SELECT P.NMPRODUTO, P.CDARVPROD, P.IDPRODATIVPR, NVL(PF.IDPRODATIV, 'A') AS IDPRODATIV
                  FROM PRODUTO P
                  RIGHT JOIN PRODFILI PF ON PF.CDFILIAL = :P_CDFILIAL
                                       AND P.CDPRODUTO = PF.CDPRODUTO
                                       AND P.NRORG = PF.NRORG
                  RIGHT JOIN RECEFILI RF ON RF.CDPRATO      = :P_CDPRATO
                                       AND RF.CDFILAUXPRAT = :P_CDFILAUXPRAT
                                       AND RF.CDPRODUTO    = P.CDPRODUTO
                                       AND RF.NRORG = P.NRORG
                 WHERE P.CDNVPRODUTO = :P_CDNVPRODUTO
                   AND P.NRORG = :P_NRORG";

        $param = array(
            "P_CDNVPRODUTO" => $maxNivelProd,
            "P_CDFILIAL" => $filial,
            "P_CDPRATO" => $prato,
            "P_CDFILAUXPRAT" => $filAux,
            "P_NRORG" => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $result = $conn->fetchAll($query, $param);
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function atualizaProdFatorCorrecaoLiquidaLocal($produto, $quantidade, $prato, $nrorg, $filAux, $quanValorNutri, $vrpefatcorlo)
    {

        $query = "UPDATE RECEFILI
                  SET VRPEFATCORLO = :VRPEFATCORLO,
                       QTPRODRECLOC = :QTPRODRECLOC,
                       QTCALCNUTRLO = :QTCALCNUTRLO
                  WHERE CDFILAUXPRAT = :OLD_CDFILAUXPRAT
                        AND CDPRATO = :OLD_CDPRATO
                        AND CDPRODUTO = :OLD_CDPRODUTO
                        AND NRORG = :OLD_NRORG";

        $param = array(
            "VRPEFATCORLO" => $vrpefatcorlo,
            "QTCALCNUTRLO" => $quanValorNutri,
            "OLD_CDPRODUTO" => $produto,
            "QTPRODRECLOC" => $quantidade,
            "OLD_CDPRATO" => $prato,
            "OLD_CDFILAUXPRAT" => $filAux,
            "OLD_NRORG" => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $param);
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function atualizaProdFatorCorrecaoBrutaLocal($produto, $quantidade, $prato, $nrorg, $filAux, $quanValorNutri, $vrpefatcorlo)
    {

        $query = "UPDATE RECEFILI
                  SET  VRPEFATCORLO = :VRPEFATCORLO,
                       QTCALCNUTRLO = :QTCALCNUTRLO,
                       QTBRUTALOUNR = :QTBRUTALOUNR,
                  WHERE CDFILAUXPRAT = :OLD_CDFILAUXPRAT
                        AND CDPRATO = :OLD_CDPRATO
                        AND CDPRODUTO = :OLD_CDPRODUTO
                        AND NRORG = :OLD_NRORG";

        $param = array(
            "VRPEFATCORLO" => $vrpefatcorlo,
            "QTCALCNUTRLO" => $quanValorNutri,
            "QTBRUTALOUNR" => $quantidade,
            "OLD_CDPRODUTO" => $produto,
            "OLD_CDPRATO" => $prato,
            "OLD_CDFILAUXPRAT" => $filAux,
            "OLD_NRORG" => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $param);
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function deletaReceita ($cdprato, $cdfilauxprat, $cdfilidest, $nrorg) {
        $query = "DELETE FROM RECEFILI
                      WHERE
                      CDPRATO      = :CDPRATDEST   AND
                      CDFILAUXPRAT = :CDFILAUXDEST AND
                      CDFILIAL     = :CDFILIDEST   AND
                      NRORG        = :NRORG";

        $param = array(
            "CDPRATDEST" => $cdprato,
            "CDFILAUXDEST" => $cdfilauxprat,
            "CDFILIDEST" => $cdfilidest,
            "NRORG" => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $param);
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }


    public static function sobrepoeReceitaLocal ($cdfilidest, $proporcao, $cdprato, $cdfilauxprat, $receitaorig,
                                                 $cdfilcentpme = null, $cdtipocard = null, $cdfiliorig,
                                                 $cdservorig, $nrorg) {
        $query = " INSERT INTO RECEFILI
                    ( CDPRATO,
                      CDFILAUXPRAT,
                      CDFILIAL,
                      CDPRODUTO,
                      QTPRODRECLOC,
                      SGUNIDADE,
                      VRPEFATCORLO,
                      VRPEFATCOCLO,
                      HRTEMPPREPLO,
                      QTUNIDESTLO,
                      QTBRUTALO,
                      CDAPRERECE,
                      QTBRUTALOUNR,
                      VRPEFATNUTLO,
                      QTCALCNUTRLO,
                      IDQTDEFIXLO)

                    (SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST AS CDFILIAL, CDPRODUTO, (QTPRODPRAT * :P_PROPORCAO)   AS QTPRODUTO,
                       SGUNIDADE, VRPEFATCORPR  AS VRPEFATCOR, VRPEFATCOCPR  AS VRPEFATCOC, HRTEMPPREPPR  AS HRTEMPPREP,
                       (QTUNIDESTPR * :PROPORCAO)  AS QTDERECE, (QTBRUTAPR * :PROPORCAO)    AS QTBRUTA, CDAPRERECE,
                       (QTBRUTAPRUNR * :PROPORCAO)  AS    QTBRUTAUNR, VRPEFATNUTPR   AS  VRPEFATNUT,(QTCALCNUTRPR * :PROPORCAO)
                       AS   QTCALCNUTR, IDQTDEFIXPR
                     FROM RECEPADR
                     WHERE (CDPRATO       = :CDPRATORIG)
                       AND (CDFILAUXPRAT  = :CDFILAUXORIG)
                       AND (:IDTIPORECE = 'P')

                     UNION ALL

                     SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST AS CDFILIAL, CDPRODUTO, (QTPRODPRATTP * :PROPORCAO) AS QTPRODUTO,
                        SGUNIDADE, VRPEFATCORPRTP AS VRPEFATCOR, VRPEFATCOCPRTP AS VRPEFATCOC, HRTEMPPREPPRTP AS HRTEMPPREP,
                        (QTUNIDESTPRTP * :PROPORCAO) AS QTDERECE, (QTBRUTAPRTP * :PROPORCAO) AS QTBRUTA, CDAPRERECE,
                        (QTBRUTAPRUNRTP * :PROPORCAO) AS QTBRUTAUNR, VRPEFATNUTPRTP AS VRPEFATNUT, (QTCALCNUTRPRTP * :PROPORCAO)
                        AS QTCALCNUTR, IDQTDEFIXPRTP
                     FROM RECETPCARD
                     WHERE (CDPRATO       = :CDPRATORIG)
                       AND (CDFILAUXPRAT  = :CDFILAUXORIG)
                       AND (CDFILCENTPME  = :CDFILCENTPME)
                       AND (CDTIPOCARD    = :CDTIPOCARD)
                       AND (:P_IDTIPORECE = 'T')

                     UNION ALL

                     SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST AS CDFILIAL, CDPRODUTO, (QTPRODRECLOC * :PROPORCAO) AS QTPRODUTO,
                        SGUNIDADE, VRPEFATCORLO AS VRPEFATCOR, VRPEFATCOCLO AS VRPEFATCOC, HRTEMPPREPLO AS HRTEMPPREP,
                        (QTUNIDESTLO * :PROPORCAO)  AS QTDERECE, (QTBRUTALO * :PROPORCAO)   AS QTBRUTA, CDAPRERECE,
                        (QTBRUTALOUNR * :PROPORCAO)   AS    QTBRUTAUNR, VRPEFATNUTLO   AS  VRPEFATNUT, (QTCALCNUTRLO * :PROPORCAO)
                        AS   QTCALCNUTR, IDQTDEFIXLO
                     FROM RECEFILI
                     WHERE (CDPRATO       = :CDPRATORIG)
                       AND (CDFILAUXPRAT  = :CDFILAUXORIG)
                       AND (CDFILIAL      = :CDFILIORIG)
                       AND (:IDTIPORECE = 'F')

                     UNION ALL

                     SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST  AS CDFILIAL,  CDPRODUTO, (QTPRODRECSER * :PROPORCAO) AS QTPRODUTO,
                        SGUNIDADE, VRPEFATCORSE AS VRPEFATCOR, VRPEFATCOCSE AS VRPEFATCOC, HRTEMPPREPSE AS HRTEMPPREP,
                        (QTUNIDESTSE * :PROPORCAO) AS QTDERECE, (QTBRUTASE * :PROPORCAO)   AS QTBRUTA, CDAPRERECE,
                        (QTBRUTASEUNR * :PROPORCAO)  AS    QTBRUTAUNR, VRPEFATNUTSE   AS  VRPEFATNUT, (QTCALCNUTRSE * :PROPORCAO)
                        AS   QTCALCNUTR, IDQTDEFIXSE
                     FROM RECESERV
                     WHERE (CDPRATO       = :CDPRATORIG)
                       AND (CDFILAUXPRAT  = :CDFILAUXORIG)
                       AND (CDFILIAL      = :CDFILIORIG)
                       AND (CDSERVFILI    = :CDSERVORIG)
                       AND (:IDTIPORECE = 'S')
   )";

        $param = array(
            "CDFILIDEST"   => $cdfilidest,
            "PROPORCAO"    => $proporcao,
            "CDPRATORIG"   => $cdprato,
            "CDFILAUXORIG" => $cdfilauxprat,
            "IDTIPORECE"   => $receitaorig,
            "CDFILCENTPME" => $cdfilcentpme,
            "CDTIPOCARD"   => $cdtipocard,
            "CDFILIORIG"   => $cdfiliorig,
            "CDSERVORIG"   => $cdservorig,
            "NRORG"        => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $param);
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }
	
	public static function acrescentaReceitaLocal ($cdfilidest, $proporcao, $cdprato, $cdfilauxprat, $receitaorig,
                                                 $cdfiliorig, $cdservorig, $nrorg)
    {

        $query = " INSERT INTO RECEFILI
                    ( CDPRATO,
                      CDFILAUXPRAT,
                      CDFILIAL,
                      CDPRODUTO,
                      QTPRODRECLOC,
                      SGUNIDADE,
                      VRPEFATCORLO,
                      VRPEFATCOCLO,
                      HRTEMPPREPLO,
                      QTUNIDESTLO,
                      QTBRUTALO,
                      CDAPRERECE,
                      QTBRUTALOUNR,
                      VRPEFATNUTLO,
                      QTCALCNUTRLO,
                      IDQTDEFIXLO )

                    ( SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST AS CDFILIAL, CDPRODUTO, (QTPRODPRAT * :PROPORCAO) AS QTPRODUTO, SGUNIDADE,
                        VRPEFATCORPR AS VRPEFATCOR, VRPEFATCOCPR AS VRPEFATCOC, HRTEMPPREPPR AS HRTEMPPREP,(QTUNIDESTPR * :PROPORCAO)
                        AS QTDERECE, (QTBRUTAPR * :PROPORCAO) AS QTBRUTA, CDAPRERECE, (QTBRUTAPRUNR * :PROPORCAO) AS QTBRUTAUNR,
                        VRPEFATNUTPR AS VRPEFATNUT, (QTCALCNUTRPR * :PROPORCAO) AS QTCALCNUTR, IDQTDEFIXPR
                      FROM
                        RECEPADR
                      WHERE
                        (CDPRATO       = :CDPRATO)   AND
                        (CDFILAUXPRAT  = :CDFILAUX)  AND
                        (:IDTIPORECE   = 'P')        AND
                        (CDPRODUTO NOT IN ( SELECT CDPRODUTO
                                             FROM RECEFILI
                                             WHERE
                                               CDPRATO      = :CDPRATO   AND
                                               CDFILAUXPRAT = :CDFILAUX  AND
                                               CDFILIAL     = :CDFILIDEST ))

                    UNION ALL


                    SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST   AS CDFILIAL, CDPRODUTO, (QTPRODRECLOC * :PROPORCAO) AS QTPRODUTO,
                      SGUNIDADE, VRPEFATCORLO AS VRPEFATCOR, VRPEFATCOCLO AS VRPEFATCOC, HRTEMPPREPLO AS HRTEMPPREP, (QTUNIDESTLO * :PROPORCAO) AS QTDERECE,
                      (QTBRUTALO * :PROPORCAO) AS QTBRUTA, CDAPRERECE, (QTBRUTALOUNR * :PROPORCAO) AS QTBRUTAUNR, VRPEFATNUTLO   AS  VRPEFATNUT,
                      (QTCALCNUTRLO * :PROPORCAO) AS   QTCALCNUTR, IDQTDEFIXLO
                    FROM
                      RECEFILI
                    WHERE
                      (CDPRATO       = :CDPRATO)    AND
                      (CDFILAUXPRAT  = :CDFILAUX)   AND
                      (CDFILIAL      = :CDFILIORIG) AND
                      (:IDTIPORECE   = 'L')         AND
                      (CDPRODUTO NOT IN ( SELECT CDPRODUTO
                                            FROM RECEFILI
                                          WHERE
                                            CDPRATO      = :CDPRATO   AND
                                            CDFILAUXPRAT = :CDFILAUX  AND
                                            CDFILIAL     = :CDFILIDEST ))

                    UNION ALL

                    SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST AS CDFILIAL, CDPRODUTO, (QTPRODRECSER * :PROPORCAO) AS QTPRODUTO, SGUNIDADE,
                      VRPEFATCORSE AS VRPEFATCOR, VRPEFATCOCSE AS VRPEFATCOC, HRTEMPPREPSE AS HRTEMPPREP, (QTUNIDESTSE * :PROPORCAO) AS QTDERECE,
                      (QTBRUTASE * :PROPORCAO)   AS QTBRUTA, CDAPRERECE, (QTBRUTASEUNR * :PROPORCAO)  AS    QTBRUTAUNR, VRPEFATNUTSE   AS  VRPEFATNUT,
                      (QTCALCNUTRSE * :PROPORCAO) AS   QTCALCNUTR, IDQTDEFIXSE
                    FROM
                      RECESERV
                    WHERE
                      (CDPRATO       = :CDPRATO)    AND
                      (CDFILAUXPRAT  = :CDFILAUX)   AND
                      (CDFILIAL      = :CDFILIORIG) AND
                      (CDSERVFILI    = :CDSERVORIG) AND
                      (:IDTIPORECE   = 'S')         AND
                      (CDPRODUTO NOT IN ( SELECT CDPRODUTO
                                          FROM RECEFILI
                                          WHERE
                                            CDPRATO      = :CDPRATO   AND
                                            CDFILAUXPRAT = :CDFILAUX  AND
                                            CDFILIAL     = :CDFILIDEST ))
                    )";

        $param = array(
            "CDFILIDEST"   => $cdfilidest,
            "PROPORCAO"    => $proporcao,
            "CDPRATO"      => $cdprato,
            "CDFILAUX" => $cdfilauxprat,
            "IDTIPORECE"   => $receitaorig,
            "CDFILIORIG"   => $cdfiliorig,
            "CDSERVORIG"   => $cdservorig,
            "NRORG"        => $nrorg
        );


        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $param);
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

}